Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrCursorNotFound = errors.New("cursor not found")
ErrCursorNotFound is returned when a cursor does not exist for a chain. This is expected for clean databases starting fresh.
var ErrReorgDetected = errors.New("reorg detected")
ErrReorgDetected is returned when reorg detected
Functions ¶
func IsResponseTooBigError ¶
func IsRetryableError ¶
IsRetryableError helper function to check if the error is retriable
Types ¶
type RPCError ¶
type ReorgError ¶
func (*ReorgError) Error ¶
func (e *ReorgError) Error() string
func (*ReorgError) Is ¶
func (e *ReorgError) Is(target error) bool
Is makes ReorgError work with Error.Is()
Click to show internal directories.
Click to hide internal directories.